==> mongodb-src-r5.2.0.tar.gz: mongodb-src-r5.2.0/jstests/concurrency/fsm_workloads/auth_privilege_cache_miss.js <==
'use strict';

/**
 * auth_privilege_cache_miss.js
 *
 * Validate user permission consistency during cache miss and slow load.
 *
 * @tags: [
 * ]
 */

// Use the auth_privilege_consistency workload as a base.
load('jstests/concurrency/fsm_libs/extend_workload.js');
load('jstests/concurrency/fsm_workloads/auth_privilege_consistency.js');

var $config = extendWorkload($config, function($config, $super) {
    // Override setup() to also set cache-miss and slow load failpoints.
    const kResolveRolesDelayMS = 100;

    const originalSetup = $config.setup;
    const originalTeardown = $config.teardown;

    $config.setup = function(db, collName, cluster) {
        originalSetup(db, collName, cluster);

        const cacheBypass = {configureFailPoint: 'authUserCacheBypass', mode: 'alwaysOn'};
        const getUser = {
            configureFailPoint: 'authLocalGetUser',
            mode: 'alwaysOn',
            data: {resolveRolesDelayMS: NumberInt(kResolveRolesDelayMS)}
        };

        cluster.executeOnMongosNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
        });

        cluster.executeOnMongodNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
            assert.commandWorked(nodeAdminDB.runCommand(getUser));
        });
    };

    $config.teardown = function(db, collName, cluster) {
        const cacheBypass = {configureFailPoint: 'authUserCacheBypass', mode: 'off'};
        const getUser = {configureFailPoint: 'authLocalGetUser', mode: 'off'};

        cluster.executeOnMongosNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
        });

        cluster.executeOnMongodNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
            assert.commandWorked(nodeAdminDB.runCommand(getUser));
        });

        originalTeardown(db, collName, cluster);
    };

    return $config;
});

==> mongodb-src-r6.0.13.tar.gz: mongodb-src-r6.0.13/jstests/concurrency/fsm_workloads/auth_privilege_cache_miss.js <==
'use strict';

/**
 * auth_privilege_cache_miss.js
 *
 * Validate user permission consistency during cache miss and slow load.
 *
 * @tags: [incompatible_with_concurrency_simultaneous]
 */

// Use the auth_privilege_consistency workload as a base.
load('jstests/concurrency/fsm_libs/extend_workload.js');
load('jstests/concurrency/fsm_workloads/auth_privilege_consistency.js');

var $config = extendWorkload($config, function($config, $super) {
    // Override setup() to also set cache-miss and slow load failpoints.
    const kResolveRolesDelayMS = 100;

    const originalSetup = $config.setup;
    const originalTeardown = $config.teardown;

    $config.data.test_name = 'auth_privilege_cache_miss';

    $config.setup = function(db, collName, cluster) {
        originalSetup.call(this, db, collName, cluster);

        const cacheBypass = {configureFailPoint: 'authUserCacheBypass', mode: 'alwaysOn'};
        const getUser = {
            configureFailPoint: 'authLocalGetUser',
            mode: 'alwaysOn',
            data: {resolveRolesDelayMS: NumberInt(kResolveRolesDelayMS)}
        };

        cluster.executeOnMongosNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
        });

        cluster.executeOnMongodNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
            assert.commandWorked(nodeAdminDB.runCommand(getUser));
        });
    };

    $config.teardown = function(db, collName, cluster) {
        const cacheBypass = {configureFailPoint: 'authUserCacheBypass', mode: 'off'};
        const getUser = {configureFailPoint: 'authLocalGetUser', mode: 'off'};

        cluster.executeOnMongosNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
        });

        cluster.executeOnMongodNodes(function(nodeAdminDB) {
            assert.commandWorked(nodeAdminDB.runCommand(cacheBypass));
            assert.commandWorked(nodeAdminDB.runCommand(getUser));
        });

        originalTeardown.call(this, db, collName, cluster);
    };

    return $config;
});
